# infernal

**DOI:** [10.5281/zenodo.13739623](https://doi.org/10.5281/zenodo.13739623)

## Available Versions
- **Version 1.1.5**
  - [Download](https://zenodo.org/record/13739624/files/infernal_1.1.5.img)
  - **MD5:** `8ea5433eda70a9d3fc7bd0006f69ccf8`
  - **DOI:** [10.5281/zenodo.13739624](https://doi.org/10.5281/zenodo.13739624)
  - **Size:** 118.36 MB
  - **Binaries:** 0 available

## Binaries (10 total)

```cmalign cmcalibrate cmemit cmpress cmsearch cmbuild cmconvert cmfetch cmscan cmstat```
